Formulator
==========

Formulator is a tool to help with the creation and validation of web
forms. Form fields are stored as objects in Zope 2, in a special Form
folder.

.. contents::


Features
--------

* manage form fields through the Zope management interface.

* manage field look & feel as well as validation and processing
  behavior.

* automatic field validation.

* determine field order and group fields together.

* easy extensibility with new field types.

* online help.

* serialization of form to XML and back.


Dependencies
------------

You need to install either zeam.form. The best to install this product
is to use buildout and let it resolves the dependencies.


Code repository
---------------

You can find the code of this extension in Git:
https://github.com/infrae/Products.Formulator
